<?php
namespace Controllers; 

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Notification;



class integracaoSeniorController {
    
    protected $connection;
    
    /** @var Environment */
    private $environment; 
    private $connectionCustom;
    
    public function __construct($environment, $connection, $connectionCustom) {
        $this->environment     = $environment;
        $this->connection = $connection;
        $this->connectionCustom = $connectionCustom;
    }
    
    public function integraMaoObra(DTO\Request $request, DTO\Response $response ){
        $this->dataSourceName = "lancdespfatu";
        $rowToSave = array();
        try{
            $data = $request->getParameter("data");
            if($data != null){

                $maoObraExterna = json_decode($data, true);
                
                
                if(json_last_error_msg() != "No error")
                    throw new \Exception("Nao foi possivel converter os dados. Detalhe: " . json_last_error_msg());
                
                $this->validaParametro($maoObraExterna);
                $this->connectionCustom->updateVpdConnection($maoObraExterna['NRORG']);
                    
                $maoObraExterna["VRLANCDESFAT"] = $this->valueToFloat($maoObraExterna["VRLANCDESFAT"]);
                $maoObraExterna["VRPREVDESFAT"] = $this->valueToFloat($maoObraExterna["VRPREVDESFAT"]);
                
                try{
                    $parametros_iu =  array(
                            'P_CDFILIAL' =>  $maoObraExterna["CDFILIAL"],
                            'P_CDDESPADMFAT' => $maoObraExterna["CDDESPADMFAT"],
                            'P_DTLANCDESFAT' => $maoObraExterna["DTLANCDESFAT"],
                            'P_VRLANCDESFAT' => $maoObraExterna["VRLANCDESFAT"],
                            'P_VRPREVDESFAT' => $maoObraExterna["VRPREVDESFAT"]
                        );
                    
                    if($this->verificaMaoObra($maoObraExterna) == 0){
                        $operacao = "inserido";
                        $stmt = $this->connection->prepare("INSERT INTO LANCDESPFATU (CDFILIAL, CDDESPADMFAT, DTLANCDESFAT, VRLANCDESFAT, VRPREVDESFAT, DTINCLUSAO) 
                        VALUES (:P_CDFILIAL, :P_CDDESPADMFAT, :P_DTLANCDESFAT, :P_VRLANCDESFAT, :P_VRPREVDESFAT, SYSDATE)");
                    }else{
                        $operacao = "atualizado";
                        $stmt = $this->connection->prepare("UPDATE LANCDESPFATU
                         SET
                           VRLANCDESFAT = :P_VRLANCDESFAT,
                           VRPREVDESFAT = :P_VRPREVDESFAT,
                           DTULTATU = SYSDATE
                         WHERE
                           CDFILIAL   = :P_CDFILIAL   AND
                           CDDESPADMFAT  = :P_CDDESPADMFAT  AND
                           DTLANCDESFAT = :P_DTLANCDESFAT");
                    }
                   
                    $stmt->execute($parametros_iu);
                    
                }catch(\Exception $ex){
                    
                    throw new \Exception("Erro ao tentar inserir na base de dados, verifique os parametros e tente novamente!");
                }
                
                $response->addMessage(new Message("Registro ".$operacao." com sucesso!"));
                
            }
        }catch(\Exception $ex){
            $response->setError(new Error("Nao foi possivel processar os dados enviados --- " . $ex->getMessage(), 500));
        }
    }
    
    public function verificaMaoObra($maoObra){
        $parametros =  array(
                            'P_CDFILIAL' =>  $maoObra["CDFILIAL"],
                            'P_CDDESPADMFAT' => $maoObra["CDDESPADMFAT"],
                            'P_DTLANCDESFAT' => $maoObra["DTLANCDESFAT"]
                        );
        $stmt = $this->connection->prepare("SELECT COUNT(*)COUNT FROM LANCDESPFATU
             WHERE
               CDFILIAL   = :P_CDFILIAL   AND
               CDDESPADMFAT  = :P_CDDESPADMFAT  AND
               DTLANCDESFAT = :P_DTLANCDESFAT"); 
        $stmt->execute($parametros);
        
        $result = $stmt->fetchAll();
        
		return  $result[0]["COUNT"];
    }
    
    // Adaptado de 'General.js'
    public function valueToFloat($value) {
		if (is_string($value) && $value) {
			if (strpos($value, ',') === false && strpos($value, '.') === false) {
				return floatval($value);
			} else if (strpos($value, ',') > strpos($value, '.')) {
                $value = str_replace('.', '', $value);
                $value = str_replace(',', '.', $value);
				return floatval($value);
			} else if (strpos($value, ',') < strpos($value, '.')) {
			    $value = str_replace(',', '.', $value);
				return floatval($value);
			}
		} else {
			return $value;
		}
    }
    
    public function validaParametro($maoObra){
        $erroMensagem = "";
        if(!isset($maoObra["CDFILIAL"]))
            $erroMensagem .= " CDFILIAL -";
        
        if(!isset($maoObra["CDDESPADMFAT"]))
            $erroMensagem .= " CDDESPADMFAT -";
        
        if(!isset($maoObra["DTLANCDESFAT"]))
            $erroMensagem .= " DTLANCDESFAT -";
        
        if(!isset($maoObra["VRLANCDESFAT"]))
            $erroMensagem .= " VRLANCDESFAT -";
        
        if(!isset($maoObra["VRPREVDESFAT"]))
            $erroMensagem .= " VRPREVDESFAT -";
            
         if(!isset($maoObra["NRORG"]))
            $erroMensagem .= " NRORG -";    
        
        if(strlen($erroMensagem) > 0)
            throw new \Exception("Parametros ausentes: " . substr($erroMensagem,0, strlen($erroMensagem)-2) );
        
    }

}


